@@ -7,10 +7,7 @@
 # checks that the pipeline is correctly constructed
 # and the output is correctly formatted.
 targets::tar_test("tar_jags_rep_draws()", {
-  skip_on_cran()
-  skip_if_not_installed("dplyr")
-  skip_if_not_installed("rjags")
-  skip_if_not_installed("R2jags")
+  skips()
   tar_jags_example_file(path = "a.jags")
   tar_jags_example_file(path = "b.jags")
   targets::tar_script({
@@ -129,10 +126,7 @@ targets::tar_test("tar_jags_rep_draws()", {
 })
 
 targets::tar_test("tar_jags_rep_draws() with transform", {
-  skip_on_cran()
-  skip_if_not_installed("dplyr")
-  skip_if_not_installed("rjags")
-  skip_if_not_installed("R2jags")
+  skips()
   tar_jags_example_file(path = "a.jags")
   tar_jags_example_file(path = "b.jags")
   targets::tar_script({
@@ -177,8 +171,7 @@ targets::tar_test("tar_jags_rep_draws() with transform", {
 })
 
 targets::tar_test("tar_jags_rep_draws() correctly errors if no JAGS file", {
-  skip_if_not_installed("rjags")
-  skip_if_not_installed("R2jags")
+  skips()
   expect_error(
     tar_jags_rep_draws(
       model,
